# This is a serverless RPG API frameworks that allows you to create and manage your own RPG game.
# Prerequisites:
- Python 3.12: Python version support is determined by the AWS Lambda runtime. The latest version of Python supported by AWS Lambda is 3.12. ([AWS Lambda runtimes](https://docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html))
- Serverless Framework 4.1.3 ([Serverless Framework Installation](https://www.serverless.com/framework/docs/getting-started))
- [serverless-python-requirements](https://github.com/serverless/serverless-python-requirements)
